@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,8 +26,7 @@
 class KActionCollection;
 class QTextCharFormat;
 class QAction;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposerControler;
 class KPIMTEXTEDIT_EXPORT RichTextComposerActions : public QObject
 {
@@ -48,12 +47,11 @@ public:
 public Q_SLOTS:
     void setActionsEnabled(bool enabled);
 
-private Q_SLOTS:
+private:
     void slotUpdateCharFormatActions(const QTextCharFormat &format);
     void slotUpdateMiscActions();
 
     void setListStyle(int _styleindex);
-private:
     class RichTextComposerActionsPrivate;
     RichTextComposerActionsPrivate *const d;
 };
