@@ -37,9 +37,8 @@ using namespace KPIMTextEdit;
 
 TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
     : QWidget(parent)
-    , mHideWhenClose(true)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout;
+    QVBoxLayout *topLayout = new QVBoxLayout(this);
     QHBoxLayout *lay = new QHBoxLayout;
     topLayout->addLayout(lay);
 
@@ -74,7 +73,6 @@ TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
     connect(mReplaceWidget, &TextReplaceWidget::replaceAllText, this, &TextEditFindBarBase::slotReplaceAllText);
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
     hide();
-    setLayout(topLayout);
 }
 
 TextEditFindBarBase::~TextEditFindBarBase()
@@ -141,7 +139,7 @@ void TextEditFindBarBase::autoSearch(const QString &str)
 {
     const bool isNotEmpty = (!str.isEmpty());
     if (isNotEmpty) {
-        QTimer::singleShot(0, this, SLOT(slotSearchText()));
+        QTimer::singleShot(0, this, [this]() { slotSearchText(); });
     } else {
         clearSelections();
     }
