@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,9 +19,7 @@
 
 #include "texteditor/richtexteditor/richtexteditorwidget.h"
 
-#include <KLocalizedString>
 #include <QApplication>
-#include <KAboutData>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 int main(int argc, char **argv)
@@ -29,15 +27,10 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
 
-    KAboutData aboutData(QStringLiteral("richtexteditor_gui"), i18n("RichTextEditorTest_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for richtexteditor widget"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     KPIMTextEdit::RichTextEditorWidget *w = new KPIMTextEdit::RichTextEditorWidget();
     w->resize(800, 600);
@@ -46,4 +39,3 @@ int main(int argc, char **argv)
     delete w;
     return 0;
 }
-
